#!/bin/sh

# save current working directory
WORKING_DIR=$PWD
GWTYPE_FILE=/zentera/.gwtype

echo
date
# Install required packages
cd rpm-7

printf "\n%s\n" "Installing requried packages"
# Install zip/unzip
rpm -Uvh zip-*.x86_64.rpm
rpm -Uvh unzip-*.x86_64.rpm
rpm -Uvh traceroute-*.x86_64.rpm

rpm -Uvh net-tools-*.rpm
rpm -Uvh libpcap-*.rpm
rpm -Uvh nmap-ncat-*.rpm

rpm -Uvh ntpdate-*.x86_64.rpm
rpm -Uvh autogen-libopts-*.x86_64.rpm
rpm -Uvh ntp-*.x86_64.rpm
rpm -Uvh wget-*.x86_64.rpm
rpm -Uvh iptables-services-*.x86_64.rpm

# For CentOS 7, using iptables as firewall instead of default firewalld
systemctl stop firewalld
systemctl disable firewalld
systemctl enable iptables

if [ ! -d /zentera ];then
	mkdir /zentera
fi

if [ ! -d /zentera/home ];then
	mkdir /zentera/home
fi


printf "\n%s\n" "Installing ZNS packages"
# Install zCLI
sed -i -e '$a\' /etc/ssh/sshd_config #add newline at end of /etc/ssh/sshd_config if there is no newline
rpm -Uvh zcli*.rpm

if [ ! -d /zentera/home/zcli ];then
        mkdir /zentera/home/zcli
fi
usermod -d /zentera/home/zcli zcli

# Install zns-sg
rpm -Uvh zns-sg*.rpm

# set GW type to "zns" for zCLI
echo "zns" > $GWTYPE_FILE
chmod 600 $GWTYPE_FILE

cd ..

# Create new user "ztu", password "zentera", UID 600, shell /bin/ztsh:
printf "\n%s\n" "Creating maintenance user account: ztu..."
#useradd -m -d /home/ztu -u 600 -p $(perl -e'print crypt("zentera-zns", "zzz")') -s /bin/ztsh ztu
useradd -m -d /zentera/home/ztu -s /bin/ztsh ztu
echo ztu:zentera-zns | chpasswd


# Disable interactive prompt for the commands cp, rm and mv:
#unalias cp rm mv


# Create the directory structure:
printf "\n%s\n" "Creating software working directory structure..."
#mkdir -m 755 /zentera
chmod 755 /zentera
chcon -t default_t /zentera
for d in cfg etc log ; do mkdir -m 700 /zentera/$d; done
chown ztu:ztu /zentera/log
chmod 700 /zentera/log


# Disable unwnated services:
printf "\n%s\n" "Disabling unwanted system services: ip6tables"
for s in ip6tables; do
chkconfig --level 0123456 $s off
done

date
# Install the default Iptables settings that are tailored for the Zentera gateway boxes:
printf "\n%s\n" "Installing the default Iptables settings..."
cp -f ./zentera-default-iptables /zentera/cfg
chmod 600 /zentera/cfg
cp -f /zentera/cfg/zentera-default-iptables /etc/sysconfig/iptables

# Flush iptables setting and restart iptables
/sbin/iptables -F
service iptables restart

chown -R root:ztu /zentera/bin
chmod 755 /zentera/bin

# Install ntp service:
printf "\n%s\n" "Installing NTP service..."
chkconfig ntpd on
ntpdate pool.ntp.org

# Vulnerability patch: Qualys Vulnerability scan "Host Uptime Based on TCP TimeStamp Option"
printf "\n%s\n" "Patching system for vulnerability fix..."
echo 0 >/proc/sys/net/ipv4/tcp_timestamps

# Disallow root to login via ssh and console
printf "\n%s\n" "Disallow root to login via ssh..."
sed -i -r 's/^#?PermitRootLogin yes/PermitRootLogin no/g' /etc/ssh/sshd_config
printf "\n%s\n" "Disallow root to login from console..."
echo > /etc/securetty
printf "\n%s\n" "Disallow TCP port forwarding..."
sed -i -r 's/^#?AllowTcpForwarding yes/AllowTcpForwarding no/g' /etc/ssh/sshd_config
sed -i -r 's/^#?AllowAgentForwarding yes/AllowAgentForwarding no/g' /etc/ssh/sshd_config
sed -i -r 's/^#?X11Forwarding yes/X11Forwarding no/g' /etc/ssh/sshd_config
sed -i -r 's/^#?PermitTunnel yes/PermitTunnel no/g' /etc/ssh/sshd_config
sed -i -r 's/^#?PasswordAuthentication no/PasswordAuthentication yes/g' /etc/ssh/sshd_config
service sshd restart

# Modify ulimit settings
printf "\n%s\n" "Tuning ulimit parameters..."
cat >> /etc/security/limits.conf << EOF
*       soft    nproc   65535
*       hard    nproc   65535
*       soft    nofile  65535
*       hard    nofile  65535
EOF
sed -i 's/#DefaultLimitNOFILE=/DefaultLimitNOFILE=65535/g' /etc/systemd/system.conf


# Generate self-signed server certificate
printf "\n%s\n" "Generating self-signed server certificate..."
openssl genrsa -out server.key 2048
openssl req -subj "/C=US/ST=CA/L=San Jose/O=Zentera Systems, Inc./CN=www.zentera.net" -new -key server.key -out server.csr
openssl x509 -req -sha256 -days 365 -in server.csr -signkey server.key -out server.crt
cp server.key server.crt /zentera/bin/network-daemon


# Check password of zcli
echo zcli:zcli123 | chpasswd
if [ $? -ne 0 ];then
	echo "!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!"
	echo "Cannot assign default password for zcli."
	echo "This may caused by the policies of password complexity."
	echo "Please manually assign it by:"
	echo -e "\tpassword zcli"
	echo "!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!"
	exit 1
fi

exit

